==> unifi-5.11.10-r1.tbz2: usr/lib/unifi/webapps/ROOT/app-unifi/config/dev/config.js <==
window.unifiConfig = {
  UnifiAPILocalPath: '/data/dev/api',
  UnifiAPIBasePath: '/api',
  UnifiAPISelfPath: '/api/self',
  UnifiAPIStatusPath: '/status',
  UnifiAppSwitcherHost: 'https://dev-app-switcher.ubnt.com',
  UnifiDefaultsBasePath: 'data/defaults',
  UnifiDeployPrefix: '/manage/',
  UnifiFileBasePath: '',
  UnifiGuestBasePath: '/guest',
  UnifiPrintBasePath: '/print',
  UnifiHotspotHost: '',
  UnifiWsHost: '',
  ConnectivityDetailsUrl: 'https://dev-config.ubnt.com/cloudAccessConfig.js',
  CloudDashboardHost: 'https://dev-unifi.ubnt.com',
  UnifiDevicesEndpoint: '/api/airos/v1/unifi/devices/',
  UnifiSoftwareDownloadUrl: 'https://www.ubnt.com/download/unifi/',
  SSOAPIHostname: 'sso-stage.ubnt.com',
  SSOAPIEndpoint: '/api/sso/v1/user/self',
  SsoRegisterUrl: 'https://account-stage.ubnt.com/register',
  SsoOAuthUrl: 'https://sso-stage.ubnt.com/oauth2',
  AccountHostname: 'staging-account.ubnt.com',
  CsrfTokenUrlCheckEnabled: true,
  WebSocketEnabled: true,
  DebugInfoEnabled: false
};

window.unifiConstant = {
  GoogleMapsApiKey: 'AIzaSyB6qtK3DaaH2JiVjMm238J04wQTOuv2mbI',
  GoogleAnalyticsCloudKey: 'UA-2432820-25',
  GoogleAnalyticsDemoKey: 'UA-2432820-49',
  VERSION: '5.11.10.0',
  ShopifyApiKey: '7dbfb8a49f454a553d4a17b8d22b0970',
  ShopifyAppId: '8',
  ShopifyDomain: 'dev-store.ubnt.com'
};

window.webrtcConfig = {
  SignallingChannelType: 'AWS',
  WebRtcStartAsCaller: true,
  UseWebrtc: false,
  VersionCheckEnabled: true
};

window.unifiSharedConstant = {
  DISCOVERY_TOOL_KEY: 'hmpigflbjeapnknladcfphgkemopofig'
};

==> unifi-5.11.18.tbz2: usr/lib/unifi/webapps/ROOT/app-unifi/config/dev/config.js <==
window.unifiConfig = {
  UnifiAPILocalPath: '/data/dev/api',
  UnifiAPIBasePath: '/api',
  UnifiAPISelfPath: '/api/self',
  UnifiAPIStatusPath: '/status',
  UnifiAppSwitcherHost: 'https://dev-app-switcher.ubnt.com',
  UnifiDefaultsBasePath: 'data/defaults',
  UnifiDeployPrefix: '/manage/',
  UnifiFileBasePath: '',
  UnifiGuestBasePath: '/guest',
  UnifiPrintBasePath: '/print',
  UnifiHotspotHost: '',
  UnifiWsHost: '',
  ConnectivityDetailsUrl: 'https://dev-config.ubnt.com/cloudAccessConfig.js',
  CloudDashboardHost: 'https://dev-unifi.ubnt.com',
  UnifiDevicesEndpoint: '/api/airos/v1/unifi/devices/',
  UnifiSoftwareDownloadUrl: 'https://www.ui.com/download/unifi/',
  SSOAPIHostname: 'sso-stage.ubnt.com',
  SSOAPIEndpoint: '/api/sso/v1/user/self',
  SsoRegisterUrl: 'https://account-stage.ubnt.com/register',
  SsoOAuthUrl: 'https://sso-stage.ubnt.com/oauth2',
  AccountHostname: 'staging-account.ubnt.com',
  CsrfTokenUrlCheckEnabled: true,
  WebSocketEnabled: true,
  DebugInfoEnabled: false
};

window.unifiConstant = {
  GoogleMapsApiKey: 'AIzaSyB6qtK3DaaH2JiVjMm238J04wQTOuv2mbI',
  GoogleAnalyticsCloudKey: 'UA-2432820-25',
  GoogleAnalyticsDemoKey: 'UA-2432820-49',
  VERSION: '5.11.18.0',
  ShopifyApiKey: '7dbfb8a49f454a553d4a17b8d22b0970',
  ShopifyAppId: '8',
  ShopifyDomain: 'dev-store.ubnt.com'
};

window.webrtcConfig = {
  SignallingChannelType: 'AWS',
  WebRtcStartAsCaller: true,
  UseWebrtc: false,
  VersionCheckEnabled: true
};

window.unifiSharedConstant = {
  DISCOVERY_TOOL_KEY: 'hmpigflbjeapnknladcfphgkemopofig'
};
